@@ -3,12 +3,13 @@
 
 
 package App::Basis::Config;
-$App::Basis::Config::VERSION = '0.5';
+$App::Basis::Config::VERSION = '0.6';
 use 5.010;
 use warnings;
 use strict;
-use Moo ;
-use YAML qw( LoadFile DumpFile);
+use Moo;
+use YAML qw( Load Dump);
+use Path::Tiny;
 use Try::Tiny;
 use App::Basis;    # let us use some of the App::Basis singletons
 
@@ -21,7 +22,7 @@ has raw => (
     lazy => 1,
 
     # builder  => '_load',
-    init_arg => undef,       # dont allow setting in constructor
+    init_arg => undef,        # dont allow setting in constructor
     default  => sub { {} },
     writer   => '_set_raw'
 );
@@ -34,13 +35,18 @@ has filename => (
 
 has nostore => (
     is      => 'ro',
-    default => sub { 0 }
+    default => sub {0}
+);
+
+has die_on_error => (
+    is      => 'ro',
+    default => sub {0}
 );
 
 
 has has_data => (
     is       => 'ro',
-    default  => sub { 0 },
+    default  => sub {0},
     init_arg => undef,            # dont allow setting in constructor
     writer   => '_set_has_data'
 );
@@ -48,16 +54,16 @@ has has_data => (
 
 has changed => (
     is       => 'rw',
-    default  => sub { 0 },
-    init_arg => undef,       # dont allow setting in constructor
-                             # writer   => '_set_changed'
+    default  => sub {0},
+    init_arg => undef,     # dont allow setting in constructor
+                           # writer   => '_set_changed'
 );
 
 
 has error => (
     is       => 'ro',
-    default  => sub { undef },
-    init_arg => undef,           # dont allow setting in constructor
+    default  => sub {undef},
+    init_arg => undef,         # dont allow setting in constructor
     writer   => '_set_error'
 );
 
@@ -84,11 +90,12 @@ sub BUILD {
 
         my $config;
         try {
-            $config = LoadFile($fname);
+            $config = Load( path($fname)->slurp_utf8 );
         }
         catch {
             $self->_set_error("Could not read/processs config file $fname. $_");
         };
+        die $self->error if ( $self->error && $self->die_on_error );
 
         # if we loaded some config
         if ( keys %$config ) {
@@ -98,6 +105,8 @@ sub BUILD {
     }
     else {
         $self->_set_error("could not establish a config filename");
+        die $self->error if ( $self->die_on_error );
+
         # $self->_set_raw( {}) ;
     }
 }
@@ -112,7 +121,7 @@ sub store {
     my $status    = 0;
 
     local $YAML::Indent = 4;
-    
+
     $self->_set_error(undef);
     if ( !$filename ) {
         $filename = $self->filename;
@@ -132,12 +141,17 @@ sub store {
         # do the save
         my $cfg = $self->raw;
         try {
-            DumpFile( $filename, $cfg );
+            # do we need to create the directory to hold the file
+            if ( !-d path($filename)->dirname ) {
+                path($filename)->dirname->mkpath;
+            }
+            path($filename)->spew_utf8( Dump($cfg) );
         }
         catch {
             $self->_set_error( "Could not save config file " . $self->filename() );
             $status = 0;
         };
+        die $self->error if ( $self->error && $self->die_on_error );
         $self->changed(0);
         $status = 1;
     }
@@ -161,34 +175,37 @@ sub _split_path {
 
     my $ref = $self->raw;
     my @items = split( /[$path_separators]/, $path );
-    for ( my $i = 0; $i < scalar(@items); $i++ ) {
-        my $item = $items[$i];
-        if ( $ref->{$item} ) {
-            $ref  = $ref->{$item};
-            $done = 1;
-        }
-        else {
-            if ($value) {
-
-                # is this the last thing?
-                if ( ( $i + 1 ) == scalar(@items) ) {
-
-                    # save the value in the last node
-                    $ref->{$item} = $value;
-                }
-                else {
-                    $ref->{$item} = {};
-                }
+    try {
+        for ( my $i = 0; $i < scalar(@items); $i++ ) {
+            my $item = $items[$i];
+            if ( $ref->{$item} ) {
                 $ref  = $ref->{$item};
                 $done = 1;
             }
             else {
+                if ($value) {
 
-                # missed item
-                $done = 0;
+                    # is this the last thing?
+                    if ( ( $i + 1 ) == scalar(@items) ) {
+
+                        # save the value in the last node
+                        $ref->{$item} = $value;
+                    }
+                    else {
+                        $ref->{$item} = {};
+                    }
+                    $ref  = $ref->{$item};
+                    $done = 1;
+                }
+                else {
+
+                    # missed item
+                    $done = 0;
+                }
             }
         }
     }
+    catch {};
 
     return $done ? $ref : undef;
 }
@@ -265,7 +282,7 @@ App::Basis::Config - Manage config YAML files in a simple manner
 
 =head1 VERSION
 
-version 0.5
+version 0.6
 
 =head1 SYNOPSIS
 
@@ -342,7 +359,9 @@ access last error generated (just a descriptive string)
 Create a new instance of a config object, read config data from passed filename
 
 B<Parameters>  passed in a HASH
-    filename    - name of file to load/save config from
+    filename      - name of file to load/save config from
+    nostore       - prevent store operation (optional)
+    die_on_error  - die if we have any errors
 
 =item store
 
